---
name: Radarr Movie
description: Skills related to movie in Radarr.
---

# Radarr Movie Skill

This skill provides tools for managing movie within Radarr.

## Capabilities

- Access movie resources
